==> scandeval-1.1.3.tar.gz: scandeval-1.1.3/scandeval/benchmarks/wikiann_fo.py <==
'''NER evaluation of a language model on the Faroese WikiANN dataset'''

import logging

from .abstract import NerBenchmark


logger = logging.getLogger(__name__)


class WikiannFoBenchmark(NerBenchmark):
    '''Benchmark of language models on the Faroese WikiANN dataset.

    Args:
        cache_dir (str, optional):
            Where the downloaded models will be stored. Defaults to
            '.benchmark_models'.
        evaluate_train (bool, optional):
            Whether the models should be evaluated on the training scores.
            Defaults to False.
        verbose (bool, optional):
            Whether to print additional output during evaluation. Defaults to
            False.

    Attributes:
        name (str): The name of the dataset.
        task (str): The type of task to be benchmarked.
        metric_names (dict): The names of the metrics.
        id2label (dict or None): A dictionary converting indices to labels.
        label2id (dict or None): A dictionary converting labels to indices.
        num_labels (int or None): The number of labels in the dataset.
        label_synonyms (list of lists of str): Synonyms of the dataset labels.
        evaluate_train (bool): Whether the training set should be evaluated.
        cache_dir (str): Directory where models are cached.
        two_labels (bool): Whether two labels should be predicted.
        split_point (int or None): Splitting point of `id2label` into labels.
        verbose (bool): Whether to print additional output.
    '''
    def __init__(self,
                 cache_dir: str = '.benchmark_models',
                 evaluate_train: bool = False,
                 verbose: bool = False):
        super().__init__(name='wikiann-fo',
                         cache_dir=cache_dir,
                         evaluate_train=evaluate_train,
                         verbose=verbose)

==> scandeval-1.5.5.tar.gz: scandeval-1.5.5/scandeval/benchmarks/wikiann_fo.py <==
'''NER evaluation of a language model on the Faroese WikiANN dataset'''

import logging

from .abstract import NerBenchmark


logger = logging.getLogger(__name__)


class WikiannFoBenchmark(NerBenchmark):
    '''Benchmark of language models on the Faroese WikiANN dataset.

    Args:
        cache_dir (str, optional):
            Where the downloaded models will be stored. Defaults to
            '.benchmark_models'.
        evaluate_train (bool, optional):
            Whether the models should be evaluated on the training scores.
            Defaults to False.
            Whether to prefer Jax for the evaluation. Defaults to False.
        verbose (bool, optional):
            Whether to print additional output during evaluation. Defaults to
            False.

    Attributes:
        name (str): The name of the dataset.
        task (str): The type of task to be benchmarked.
        metric_names (dict): The names of the metrics.
        id2label (dict or None): A dictionary converting indices to labels.
        label2id (dict or None): A dictionary converting labels to indices.
        num_labels (int or None): The number of labels in the dataset.
        label_synonyms (list of lists of str): Synonyms of the dataset labels.
        evaluate_train (bool): Whether the training set should be evaluated.
        cache_dir (str): Directory where models are cached.
        two_labels (bool): Whether two labels should be predicted.
        split_point (int or None): Splitting point of `id2label` into labels.
    '''
    def __init__(self,
                 cache_dir: str = '.benchmark_models',
                 evaluate_train: bool = False,
                 verbose: bool = False):
        super().__init__(name='wikiann-fo',
                         cache_dir=cache_dir,
                         evaluate_train=evaluate_train,
                         verbose=verbose)
